<?php
/**
 * Register custom block patterns for Filr.
 *
 * @package Filr
 */

namespace filr;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class FILR_Patterns
 */
class FILR_Patterns {

	/**
	 * Instance of this class.
	 *
	 * @var FILR_Patterns
	 */
	private static $instance = null;

	/**
	 * Get instance of this class.
	 *
	 * @return FILR_Patterns
	 */
	public static function get_instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_block_patterns' ) );
	}

	/**
	 * Register custom block patterns.
	 *
	 * @return void
	 */
	public function register_block_patterns() {
		if ( ! function_exists( 'register_block_pattern' ) ) {
			return;
		}

		register_block_pattern(
			'filr/query-loop-table',
			array(
				'title'       => esc_html__( 'Filr Table View', 'filr' ),
				'description' => esc_html__( 'A table-like view for Filr items with all meta fields.', 'filr' ),
				'blockTypes'  => array( 'core/query' ),
				'categories'  => array( 'query' ),
				'content'     => '
<!-- wp:columns {"className":"filr-table-header"} -->
<div class="wp-block-columns filr-table-header">
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Title</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Extension</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Size</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Version</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Date</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Expire Downloads</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Expire Date</p><!-- /wp:paragraph --></div><!-- /wp:column -->
	<!-- wp:column --><div class="wp-block-column"><!-- wp:paragraph --><p>Link</p><!-- /wp:paragraph --></div><!-- /wp:column -->
</div>
<!-- /wp:columns -->

<!-- wp:query {"query":{"postType":"filr","perPage":10},"displayLayout":{"type":"list"}} -->
<div class="wp-block-query">
	<!-- wp:post-template -->
	<!-- wp:columns -->
	<div class="wp-block-columns">
		<!-- wp:column --><div class="wp-block-column"><!-- wp:post-title {"isLink":false, "level":0} /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/file-extension /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/file-size /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/version /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/file-date /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/expire-download /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/expire-date /--></div><!-- /wp:column -->
		<!-- wp:column --><div class="wp-block-column"><!-- wp:filr/download-button /--></div><!-- /wp:column -->
	</div>
	<!-- /wp:columns -->
	<!-- /wp:post-template -->

	<!-- wp:query-pagination {"layout":{"type":"flex","justifyContent":"center"}} -->
	<!-- wp:query-pagination-previous /-->
	<!-- wp:query-pagination-numbers /-->
	<!-- wp:query-pagination-next /-->
	<!-- /wp:query-pagination -->
</div>
<!-- /wp:query -->
',
			)
		);
	}
}
