<?php

namespace filr;

/**
 * FILR Search & Filter Integration Class
 */
class FILR_Search_Filter_Integration {


	/**
	 * Integration identifier
	 */
	private $integration_name = 'filr/downloads';

	/**
	 * Query ID from Search & Filter
	 */
	private $query_id;

	/**
	 * Constructor
	 */
	public function __construct() {
		// Get the query ID from options
		$this->query_id = get_option( 'filr_search_filter_query_id', false );

		if ( ! $this->query_id ) {
			// Create the query on first run
			add_action( 'admin_init', array( $this, 'maybe_create_search_filter_query' ) );
		}
	}

	/**
	 * Initialize the integration
	 */
	public function run() {
	}

	/**
	 * Create the Search & Filter query on first activation
	 */
	public function maybe_create_search_filter_query() {
		if ( $this->query_id ) {
			return;
		}

		// Check if Search & Filter is active
		if ( ! class_exists( 'Search_Filter' ) ) {
			return;
		}

		$query = new \Search_Filter\Queries\Query();

		// Set basic query properties
		$query->set_name( 'FILR Protected Files' );
		$query->set_status( 'enabled' );
		$query->set_css( '.search-filter-query--id-8{--search-filter-spinner-scale:3;--search-filter-spinner-margin:12px 0 0 0;--search-filter-spinner-padding:12px 12px 12px 12px;--search-filter-spinner-h-position:center;--search-filter-spinner-v-position:flex-start;--search-filter-spinner-border-width:;--search-filter-spinner-border-style:;--search-filter-spinner-border-color:;--search-filter-spinner-border-radius:4px;}' );

		// Set query attributes
		$query_data = array(
			'useIndexer'            => 'yes',
			'postTypes'             => array( 'filr' ),
			'resultsDynamicUpdate'  => 'yes',
			'resultsShowSpinner'    => 'yes',
			'resultsFadeResults'    => 'yes',
			'resultsUpdateUrl'      => 'yes',
			'resultsScrollTo'       => 'top',
			'resultsPaginationType' => 'default',
			'queryIntegration'      => 'query_block',
			'queryLoopAutodetect'   => 'yes',
			'postStatus'            => array( 'publish' ),
			'postsPerPage'          => 10,
			'resultsScrollTo'       => 'top',
			'resultsPaginationType' => 'default',
			'integrationType'       => 'dynamic',
			'queryIntegration'      => 'query_block',
			'queryLoopAutodetect'   => 'yes',
			'postStatus'            => array( 'publish' ),
			'postsPerPage'          => 10,
			'sortOrder'             => array(),
			'stickyPosts'           => 'ignore',
			'fieldRelationship'     => 'all',
			'excludeCurrentPost'    => 'yes',
			'spinnerScale'          => 3,
			'spinnerPosition'       => 'top center',
			'spinnerPadding'        => array(
				'top'    => '12px',
				'right'  => '12px',
				'bottom' => '12px',
				'left'   => '12px',
			),
			'spinnerMargin'         => array(
				'top'    => '12px',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'spinnerBorder'         => '',
			'spinnerBorderRadius'   => '4px',
		);

		$query->set_attributes( $query_data, true );
		$result = $query->save();

		if ( ! is_wp_error( $result ) ) {
			$this->query_id = $result;
			update_option( 'filr_search_filter_query_id', $this->query_id );

			// Store the integration shortcode as query meta
			\Search_Filter\Queries\Query::update_meta( $this->query_id, 'integrationShortcode', '[filr_protected_files]' );
		}
	}

	/**
	 * Register FILR as a display option in Search & Filter
	 */
	public function register_settings() {
		$integration_type_setting = \Search_Filter\Queries\Settings::get_setting( 'queryIntegration' );
		if ( $integration_type_setting ) {
			$new_integration_type_option = array(
				'label' => __( 'FILR Downloads', 'filr' ),
				'value' => $this->integration_name,
			);
			$integration_type_setting->add_option( $new_integration_type_option );
		}
	}
}
